@@ -1,9 +1,10 @@
 # <@LICENSE>
-# Copyright 2004 Apache Software Foundation
-# 
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to you under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at:
 # 
 #     http://www.apache.org/licenses/LICENSE-2.0
 # 
@@ -94,20 +95,20 @@ use vars qw{
   @site_rules_path
 };
 
-$VERSION = "3.001002";      # update after release (same format as perl $])
+$VERSION = "3.001005";      # update after release (same format as perl $])
 #$IS_DEVEL_BUILD = 1;        # change for release versions
 
 @ISA = qw();
 
 # SUB_VERSION is now just <yyyy>-<mm>-<dd>
-$SUB_VERSION = (split(/\s+/,'$LastChangedDate: 2006-05-25 09:58:05 -0700 (Thu, 25 May 2006) $ updated by SVN'))[1];
+$SUB_VERSION = (split(/\s+/,'$LastChangedDate: 2006-08-29 08:18:34 -0700 (Tue, 29 Aug 2006) $ updated by SVN'))[1];
 
 # If you hacked up your SA, you should add a version_tag to your .cf files.
 # This variable should not be modified directly.
 @EXTRA_VERSION = qw();
 if (defined $IS_DEVEL_BUILD && $IS_DEVEL_BUILD) {
   push(@EXTRA_VERSION,
-       ('r' . qw{$LastChangedRevision: 409413 $ updated by SVN}[1]));
+       ('r' . qw{$LastChangedRevision: 438093 $ updated by SVN}[1]));
 }
 
 sub Version {
@@ -124,7 +125,7 @@ $HOME_URL = "http://spamassassin.apache.org/";
 @default_rules_path = (
   './rules',              # REMOVEFORINST
   '../rules',             # REMOVEFORINST
-  '__local_state_dir__/spamassassin/__version__',
+  '__local_state_dir__/__version__',
   '__def_rules_dir__',
   '__prefix__/share/spamassassin',
   '/usr/local/share/spamassassin',
@@ -247,7 +248,37 @@ effective UID under UNIX).
 
 If none of C<rules_filename>, C<site_rules_filename>, C<userprefs_filename>, or
 C<config_text> is set, the C<Mail::SpamAssassin> module will search for the
-configuration files in the usual installed locations.
+configuration files in the usual installed locations using the below variable
+definitions which can be passed in.
+
+=over 4
+
+=item PREFIX
+
+Used as the root for certain directory paths such as:
+
+  '__prefix__/etc/mail/spamassassin'
+  '__prefix__/etc/spamassassin'
+
+Defaults to "@@PREFIX@@".
+
+=item DEF_RULES_DIR
+
+Location where the default rules are installed.  Defaults to
+"@@DEF_RULES_DIR@@".
+
+=item LOCAL_RULES_DIR
+
+Location where the local site rules are installed.  Defaults to
+"@@LOCAL_RULES_DIR@@".
+
+=item LOCAL_STATE_DIR
+
+Location of the local state directory, mainly used for installing updates via
+C<sa-update>.  Defaults to "@@LOCAL_STATE_DIR@@".
+
+=back
+
 
 =cut
 
@@ -272,8 +303,12 @@ sub new {
   dbg("generic: SpamAssassin version " . Version());
 
   # if the libs are installed in an alternate location, and the caller
-  # didn't set PREFIX, we should have an estimated guess ready ...
-  $self->{PREFIX} ||= '@@PREFIX@@';  # substituted at 'make' time
+  # didn't set PREFIX, we should have an estimated guess ready, values
+  # substituted at 'make' time
+  $self->{PREFIX}		||= '@@PREFIX@@';
+  $self->{DEF_RULES_DIR}	||= '@@DEF_RULES_DIR@@';
+  $self->{LOCAL_RULES_DIR}	||= '@@LOCAL_RULES_DIR@@';
+  $self->{LOCAL_STATE_DIR}	||= '@@LOCAL_STATE_DIR@@';
 
   $self->{conf} ||= new Mail::SpamAssassin::Conf ($self);
   $self->{plugins} = Mail::SpamAssassin::PluginHandler->new ($self);
@@ -561,7 +596,7 @@ Finish learning.
 
 sub finish_learner {
   my $self = shift;
-  $self->{bayes_scanner}->finish();
+  $self->{bayes_scanner}->sanity_check_is_untied(1);
   1;
 }
 
@@ -1235,9 +1270,14 @@ sub lint_rules {
   $self->{lint_rules} = $self->{conf}->{lint_rules} = 1;
   $self->{syntax_errors} = 0;
 
+  my $olddcp = $self->{dont_copy_prefs};
+  $self->{dont_copy_prefs} = 1;
+
   $self->init(1);
   $self->{syntax_errors} += $self->{conf}->{errors};
 
+  $self->{dont_copy_prefs} = $olddcp;       # revert back to previous
+
   my $mail = $self->parse(\@testmsg, 1);
   my $status = Mail::SpamAssassin::PerMsgStatus->new($self, $mail,
                         { disable_auto_learning => 1 } );
@@ -1353,14 +1393,15 @@ sub init {
       $fname = $self->{userprefs_filename};
       $fname ||= $self->first_existing_path (@default_userprefs_path);
 
-      if (defined $fname) {
-        if (!-f $fname && !$self->{dont_copy_prefs} && !$self->create_default_prefs($fname)) {
+      if (!$self->{dont_copy_prefs}) {
+        # bug 4932: if the userprefs path doesn't exist, we need to make it, so
+        # just use the last entry in the array as the default path.
+        $fname ||= $self->sed_path($default_userprefs_path[-1]);
+
+	if (!-f $fname && !$self->create_default_prefs($fname)) {
           warn "config: failed to create default user preference file $fname\n";
         }
       }
-      else {
-	warn "config: could not find userprefs file\n";
-      }
 
       $self->{config_text} .= $self->read_cf ($fname, 'user prefs file');
     }
@@ -1472,18 +1513,19 @@ sub get_and_create_userstate_dir {
 
   $fname ||= $self->first_existing_path (@default_userstate_dir);
 
-  if (defined $fname) {
-    if (!$self->{dont_copy_prefs}) {
-      dbg("config: using \"$fname\" for user state dir");
-    }
+  # bug 4932: use the last default_userstate_dir entry if none of the others
+  # already exist
+  $fname ||= $self->sed_path($default_userstate_dir[-1]);
 
-    if (!-d $fname) {
-      # not being able to create the *dir* is not worth a warning at all times
-      eval { mkpath($fname, 0, 0700) } or dbg("config: mkdir $fname failed: $@ $!\n");
-    }
+  if (!$self->{dont_copy_prefs}) {
+    dbg("config: using \"$fname\" for user state dir");
   }
-  else {
-    info("config: can not determine userstate dir\n");
+
+  # bug 4932: we always want to make the userstate directory, even if
+  # dont_copy_prefs is true for things like bayes, awl, etc.
+  if (!-d $fname) {
+    # not being able to create the *dir* is not worth a warning at all times
+    eval { mkpath($fname, 0, 0700) } or dbg("config: mkdir $fname failed: $@ $!\n");
   }
 
   $fname;
@@ -1800,10 +1842,11 @@ E<lt>http://wiki.apache.org/spamassassin/E<gt> for more information.
 Mail::SpamAssassin::Conf(3)
 Mail::SpamAssassin::PerMsgStatus(3)
 spamassassin(1)
+sa-update(1)
 
 =head1 BUGS
 
-See E<lt>http://bugzilla.spamassassin.org/E<gt>
+See E<lt>http://issues.apache.org/SpamAssassin/E<gt>
 
 =head1 AUTHORS
 
